<?php
/**
 * Custom functions
 *
 * @package Yudlee Themes
 * @subpackage Whitish Lite
 * @since Whitish Lite 1.0
 */

/****************** Whitish Lite DISPLAY COMMENT NAVIGATION *******************************/
if (! function_exists('whitish_lite_comment_nav')) {
	function whitish_lite_comment_nav() {
		if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
		?>
		<nav class="navigation comment-navigation" role="navigation">
			<h2 class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'whitish-lite' ); ?></h2>
			<div class="nav-links">
				<?php
					if ( $prev_link = get_previous_comments_link( __( 'Older Comments', 'whitish-lite' ) ) ) :
						printf( '<div class="nav-previous">%s</div>', esc_html($prev_link) );
					endif;
					if ( $next_link = get_next_comments_link( __( 'Newer Comments', 'whitish-lite' ) ) ) :
						printf( '<div class="nav-next">%s</div>', esc_html($next_link) );
					endif;
				?>
			</div><!-- .nav-links -->
		</nav><!-- .comment-navigation -->
		<?php
		endif;
	}
}
/******************** Remove div and replace with ul**************************************/
if (! function_exists('whitish_lite_wp_page_menu')) {
	add_filter('wp_page_menu', 'whitish_lite_wp_page_menu');
	function whitish_lite_wp_page_menu($page_markup) {
		preg_match('/^<div class=\"([a-z0-9-_]+)\">/i', $page_markup, $matches);
		$divclass   = $matches[1];
		$replace    = array('<div class="'.$divclass.'">', '</div>');
		$new_markup = str_replace($replace, '', $page_markup);
		$new_markup = preg_replace('/^<ul>/i', '<ul class="'.$divclass.'">', $new_markup);
		return $new_markup;
	}
}
/***************Pass slider effect  parameters from php files to jquery file ********************/
if (! function_exists('whitish_lite_slider_value')) {
	function whitish_lite_slider_value() {
		$whitish_lite_transition_effect   = 'fade';
		$whitish_lite_transition_delay    = 4*1000;
		$whitish_lite_transition_duration = 1*1000;
		wp_localize_script(
			'whitish-lite-slider',
			'whitish_lite_slider_value',
			array(
				'transition_effect'   => $whitish_lite_transition_effect,
				'transition_delay'    => $whitish_lite_transition_delay,
				'transition_duration' => $whitish_lite_transition_duration,
			)
		);
	}
}
/********************* Used wp_page_menu filter hook *********************************************/
if (! function_exists('whitish_lite_wp_page_menu_filter')) {
	function whitish_lite_wp_page_menu_filter($text) {
		$replace = array(
			'current_page_item' => 'current-menu-item',
		);
		$text = str_replace(array_keys($replace), $replace, $text);
		return $text;
	}
	add_filter('wp_page_menu', 'whitish_lite_wp_page_menu_filter');
}

/**************************************************************************************/
if (! function_exists('whitish_lite_get_featured_posts')) {
	function whitish_lite_get_featured_posts() {
		return apply_filters( 'whitish_lite_get_featured_posts', array() );
	}
}
/************ Return bool if there are featured Posts ********************************/
if (! function_exists('whitish_lite_has_featured_posts')) {
	function whitish_lite_has_featured_posts() {
		return ! is_paged() && (bool) whitish_lite_get_featured_posts();
	}
}

add_filter( 'get_the_archive_title', function ( $title ) {
	$format = get_post_format();
	$whitish_lite_settings = whitish_lite_get_theme_options();
    if( is_archive() ) {
			if ( is_category() ) :
				$whitish_lite_header_title = esc_html__( 'Category: ', 'whitish-lite' ). ucfirst(single_cat_title( '', FALSE ));
			elseif ( is_tag() ) :
				if($whitish_lite_settings['whitish_lite_blog_layout'] != 'photography_layout' ):
					$whitish_lite_header_title = esc_html__( 'Tag: ', 'whitish-lite' ). ucfirst(single_tag_title( '', FALSE ));
				endif;

			elseif ( is_author() ) :
				the_post();
				$whitish_lite_header_title = esc_html__('Author: ', 'whitish-lite'). ucfirst(get_the_author());
			elseif ( is_day() ) :
				$whitish_lite_header_title = esc_html__('Day: ', 'whitish-lite'). get_the_date();
			elseif ( is_month() ) :
				$whitish_lite_header_title = esc_html__('Month: ', 'whitish-lite'). get_the_date('F Y' );
			elseif ( is_year() ) :
				$whitish_lite_header_title = esc_html__('Year: ', 'whitish-lite'). get_the_date('Y' );
			elseif ( $format == 'audio' ) :
				$whitish_lite_header_title = esc_html__( 'Audios', 'whitish-lite' );
			elseif ( $format =='aside' ) :
				$whitish_lite_header_title = esc_html__( 'Asides', 'whitish-lite');
			elseif ( $format =='image' ) :
				$whitish_lite_header_title = esc_html__( 'Images', 'whitish-lite' );
			elseif ( $format =='gallery' ) :
				$whitish_lite_header_title = esc_html__( 'Galleries', 'whitish-lite' );
			elseif ( $format =='video' ) :
				$whitish_lite_header_title = esc_html__( 'Videos', 'whitish-lite' );
			elseif ( $format =='status' ) :
				$whitish_lite_header_title = esc_html__( 'Status', 'whitish-lite' );
			elseif ( $format =='quote' ) :
				$whitish_lite_header_title = esc_html__( 'Quotes', 'whitish-lite' );
			elseif ( $format =='link' ) :
				$whitish_lite_header_title = esc_html__( 'links', 'whitish-lite' );
			elseif ( $format =='chat' ) :
				$whitish_lite_header_title = esc_html__( 'Chats', 'whitish-lite' );
			elseif ( class_exists('WooCommerce') && (is_shop() || is_product_category()) ):
	  			$whitish_lite_header_title = woocommerce_page_title( false );
	  		elseif ( class_exists('bbPress') && is_bbpress()) :
	  			$whitish_lite_header_title = esc_html(get_the_title());
			else :
				$whitish_lite_header_title = sprintf( esc_html__( 'Archive:', 'whitish-lite' ), '<span>' . the_archive_title() . '</span>' );
			endif;
		} elseif (is_home()){
			$whitish_lite_header_title = esc_html(get_the_title(get_option( 'page_for_posts' )) );
		} elseif (is_404()) {
			$whitish_lite_header_title = __('Page NOT Found', 'whitish-lite');
		} elseif (is_search()) {
			$search_query = get_search_query();
			$whitish_lite_header_title = sprintf( 'Search Results for: '.ucfirst($search_query).'', 'whitish-lite' );
			 	} elseif (is_page_template()) {
			$whitish_lite_header_title = esc_html(get_the_title());
		} else {
			$whitish_lite_header_title = esc_html(get_the_title());
		}
		return $whitish_lite_header_title;

});

/****************** Footer Menu *************************/
if (! function_exists('whitish_lite_footer_menu_section')) {
	function whitish_lite_footer_menu_section(){
		if(has_nav_menu('footermenu')):
			$args = array(
				'theme_location' => 'footermenu',
				'container'      => '',
				'items_wrap'     => '<ul>%3$s</ul>',
			);
			echo '<nav id="footer-navigation">';
			wp_nav_menu($args);
			echo '</nav><!-- end #footer-navigation -->';
		endif;
	}
	add_action( 'whitish_lite_footer_menu', 'whitish_lite_footer_menu_section' );
}


if ( ! function_exists( 'whitish_lite_the_featured_video' ) ) {
    function whitish_lite_the_featured_video( $content ) {

        $ori_url = explode( "\n", esc_html( $content ) );
        $url = esc_url( $ori_url[0] );

        $w = get_option( 'embed_size_w' );
        if ( !is_single() )
            $url = str_replace( '448', $w, $url );

        if ( 0 === strpos( $url, 'https://' ) ) {
            $embed_url = wp_oembed_get( esc_url( $url ) );
            print_r($embed_url);
            $content = trim( str_replace( $url, '', esc_html( $content ) ) );
        }
        elseif ( preg_match ( '#^<(script|iframe|embed|object)#i', $url ) ) {
            $h = get_option( 'embed_size_h' );
            echo esc_url( $url );
            if ( !empty( $h ) ) {

                if ( $w === $h ) $h = ceil( $w * 0.75 );
                $url = preg_replace(
                    array( '#height="[0-9]+?"#i', '#height=[0-9]+?#i' ),
                    array( sprintf( 'height="%d"', $h ), sprintf( 'height=%d', $h ) ),
                    $url
                    );
                echo esc_url( $url );
            }

            $content = trim( str_replace( $url, '', $content ) );
        }
    }
}

if (! function_exists('whitish_lite_single_content')) {
    function whitish_lite_single_content($post) {
        $content = trim(  get_post_field('post_content', $post->ID) );
        $new_content =  preg_match_all("/\[[^\]]*\]/", $content, $matches);
        if ( has_post_format('gallery')) {
            echo wp_kses_post(strip_shortcodes($post->post_content));
        }
        else {
            the_content();
        }
    }
}